Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct Publisher

pub struct Publisher<T, P>{ /* private fields */ }
Publisher implemented over a selected-wire zero-copy transport.

Implementations

Source

impl<T, P> Publisher<T, P>

pub fn new(transport: Arc<T>, uri_provider: Arc<P>) -> Self

Creates a publisher over a zero-copy transport.

Source

impl<T, P> Publisher<T, P>

pub async fn publish_stable<Payload>( &self, resource_id: u16, call_options: CallOptions, init: impl for<'payload> FnOnce(&'payload mut Payload) + Send, ) -> Result<(), PubSubError>
where T::Wire: UWirePayload<Payload>, <T::Wire as UWirePayload<Payload>>::Codec: LoanPayload<Payload> + Send + Sync,

Publishes an initialized stable payload using the transport endpoint’s selected wire.

Source

impl<T, P> Publisher<T, P>

pub async fn publish_uninit_stable<Payload>( &self, resource_id: u16, call_options: CallOptions, init: impl for<'payload> FnOnce(StablePayloadInitContext<'payload, Payload>) -> Result<InitializedStablePayload<'payload, Payload>, UWireError> + Send, ) -> Result<(), PubSubError>
where T::Wire: UWirePayload<Payload, Codec = StableContainerPayload<Payload>>, Payload: StablePayloadInit + Send,

Publishes a stable payload by initializing it directly in uninitialized transport storage.