pub struct Publisher<T, P>{ /* private fields */ }Expand description
Publisher implemented over a selected-wire zero-copy transport.
Implementations
Sourceimpl<T, P> Publisher<T, P>
impl<T, P> Publisher<T, P>
Sourcepub async fn publish_stable<Payload>(
&self,
resource_id: u16,
call_options: CallOptions,
init: impl for<'payload> FnOnce(&'payload mut Payload) + Send,
) -> Result<(), PubSubError>where
T::Wire: UWirePayload<Payload>,
<T::Wire as UWirePayload<Payload>>::Codec: LoanPayload<Payload> + Send + Sync,
pub async fn publish_stable<Payload>(
&self,
resource_id: u16,
call_options: CallOptions,
init: impl for<'payload> FnOnce(&'payload mut Payload) + Send,
) -> Result<(), PubSubError>where
T::Wire: UWirePayload<Payload>,
<T::Wire as UWirePayload<Payload>>::Codec: LoanPayload<Payload> + Send + Sync,
Publishes an initialized stable payload using the transport endpoint’s selected wire.
Sourceimpl<T, P> Publisher<T, P>
impl<T, P> Publisher<T, P>
Sourcepub async fn publish_uninit_stable<Payload>(
&self,
resource_id: u16,
call_options: CallOptions,
init: impl for<'payload> FnOnce(StablePayloadInitContext<'payload, Payload>) -> Result<InitializedStablePayload<'payload, Payload>, UWireError> + Send,
) -> Result<(), PubSubError>where
T::Wire: UWirePayload<Payload, Codec = StableContainerPayload<Payload>>,
Payload: StablePayloadInit + Send,
pub async fn publish_uninit_stable<Payload>(
&self,
resource_id: u16,
call_options: CallOptions,
init: impl for<'payload> FnOnce(StablePayloadInitContext<'payload, Payload>) -> Result<InitializedStablePayload<'payload, Payload>, UWireError> + Send,
) -> Result<(), PubSubError>where
T::Wire: UWirePayload<Payload, Codec = StableContainerPayload<Payload>>,
Payload: StablePayloadInit + Send,
Publishes a stable payload by initializing it directly in uninitialized transport storage.